@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemManager.h 2756 2007-12-11 10:57:59Z svn $
+ * $Id: UploadItemManager.h 2772 2008-01-24 16:25:23Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_ITEM_MANAGER_H
@@ -63,6 +63,7 @@ public:
     UploadItem *get_item(apr_pool_t *pool, apr_size_t item_id);
     apr_file_t *get_item_file(apr_pool_t *pool, apr_size_t item_id,
                               bool is_sendfile_enabled=false);
+    void update_atime(apr_size_t item_id);
     apr_time_t get_mtime() const
     {
         return *mtime_;
@@ -135,7 +136,9 @@ private:
                         const char *download_pass, const char *comment,
                         const char *code_pat, const char *ip_address);
     void remove_impl(apr_pool_t *pool, UploadItem *uitem);
+    void remove_files(apr_pool_t *pool, apr_uint64_t file_size);
     void remove_old_files(apr_pool_t *pool, apr_uint64_t file_size);
+    void remove_unpopular_files(apr_pool_t *pool, apr_uint64_t file_size);
 
     /**
      * ユニークなアイテム ID とインデックスを生成します．
