@@ -45,7 +45,7 @@ sub create_exp {
 sub ssh_login {
     my $exp = shift;
 
-    $exp->spawn('ssh', MAC_HOSTNAME) or die $!;
+    $exp->spawn('cocot', qw(-t EUC-JP -p UTF-8 ssh), MAC_HOSTNAME) or die $!;
     $exp->expect(CMD_TIMEOUT_SEC, MAC_HOSTNAME . '%');
 }
 
@@ -73,13 +73,6 @@ sub make_config {
     $exp->expect(CMD_TIMEOUT_SEC, MAC_HOSTNAME . '%');
 }
 
-sub cd_src_dir {
-    my $exp = shift;
-
-    $exp->send('cd src' . "\n");
-    $exp->expect(CMD_TIMEOUT_SEC, MAC_HOSTNAME . '%');
-}
-
 sub make_check {
     my $exp = shift;
 
@@ -89,10 +82,13 @@ sub make_check {
     $exp->send('make WITH_COLOR=1' . "\n");
     $exp->expect(MAKE_TIMEOUT_SEC, MAC_HOSTNAME . '%');
 
-    $exp->send('make clean-obj WITH_COLOR=1' . "\n");
+    $exp->send('sudo make -f GNUmakefile.apache install WITH_COLOR=1' . "\n");
     $exp->expect(MAKE_TIMEOUT_SEC, MAC_HOSTNAME . '%');
 
-    $exp->send('make test-run WITH_COLOR=1' . "\n");
+    $exp->send('make -C src clean-obj WITH_COLOR=1' . "\n");
+    $exp->expect(MAKE_TIMEOUT_SEC, MAC_HOSTNAME . '%');
+
+    $exp->send('make -C src test-run WITH_COLOR=1' . "\n");
     $exp->expect(MAKE_TIMEOUT_SEC, MAC_HOSTNAME . '%');
 }
 
@@ -107,8 +103,6 @@ cd_top_dir($exp);
 svn_update($exp);
 # 
 make_config($exp);
-# ǥ쥯ȥΰư
-cd_src_dir($exp);
 # ѥ
 make_check($exp);
 
